@@ -11,12 +11,22 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""Provide configuration object name resolution
+"""
+Provide configuration object name resolution.
+
+.. note:: This module is no longer used by `zope.configuration` and
+   may be deprecated soon. Its functions are not documented.
 """
 
 import os
 from types import ModuleType
 
+__all__ = [
+    'resolve',
+    'getNormalizedName',
+    'path',
+]
+
 def resolve(name, package='zopeproducts', _silly=('__doc__',), _globals={}):
     name = name.strip()
 
